==> cramr_ui_lib-1.0.13.tar.gz: lib/routes/learn_or_repeat_route.dart <==
import 'package:cramr_ui_lib/routes/repeat_selection_route.dart';
import 'package:cramr_ui_lib/routes/verb_selectionmode_selection_route.dart';
import 'package:flutter/material.dart';

import '../ads/safe_banner_ad_widget.dart';
import '../settings/settings_controller.dart';
import '../settings/settings_view.dart';
import '../theme/custom_theme.dart';
import '../util/text_size_limiter.dart';

class LearnOrRepeatRoute extends StatefulWidget {
  static const routeName = '/learnOrRepeatRoute';

  final SettingsController settingsController;
  final SafeBannerAdWidget safeBannerAdWidget;

  const LearnOrRepeatRoute(
      {super.key,
      required this.settingsController,
      required this.safeBannerAdWidget});

  @override
  State<StatefulWidget> createState() => LearnOrRepeatRouteState();
}

class LearnOrRepeatRouteState extends State<LearnOrRepeatRoute> {
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: widget.settingsController,
        builder: (BuildContext context, Widget? child) {
          return MaterialApp(
              debugShowCheckedModeBanner: false,
              themeMode: widget.settingsController.themeMode,
              theme: CustomTheme.lightTheme,
              darkTheme: ThemeData.dark(),
              home: SafeArea(
                  child: Scaffold(
                appBar: AppBar(
                  actions: [_settingsIcon(context)],
                ),
                body: Column(
                  children: [
                    Expanded(
                        child: ListView(
                      key: const Key('LearnOrRepeatListView'),
                      children: [
                        _buildCard(context, const Key('repeat_key'), 'repeat',
                            'Je répète', 'Ik herhaal'),
                        _buildCard(context, const Key('learn_key'), 'learn',
                            'J\'apprends', 'Ik leer'),
                      ],
                    )),
                    Container(
                      height: 100.0,
                      alignment: Alignment.center,
                      child: widget.safeBannerAdWidget,
                    )
                  ],
                ),
              )));
        });
  }

  Widget _buildCard(BuildContext context, Key buttonKey, String mode,
      String modeName, String modeTranslation) {
    return Center(
      child: SizedBox(
        width: MediaQuery.of(context).size.width * .95,
        child: Card(
          margin: const EdgeInsets.fromLTRB(30, 15, 30, 15),
          elevation: 20,
          child: Column(
            children: [
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: Text(
                  modeName,
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline3,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                child: Text(
                  '($modeTranslation)',
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline6,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                  padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                  child: OutlinedButton(
                    key: buttonKey,
                    onPressed: () {
                      _launchNextRoute(context, mode);
                    },
                    style: TextButton.styleFrom(primary: Colors.blue),
                    child: _iconLearnOrRepeat(mode),
                  )),
            ],
          ),
        ),
      ),
    );
  }

  Widget _iconLearnOrRepeat(String mode) {
    if ('repeat' == mode) {
      return const Icon(Icons.refresh);
    } else if ('learn' == mode) {
      return const Icon(Icons.add);
    }
    return const Icon(Icons.adb_sharp);
  }

  void _launchNextRoute(BuildContext context, String mode) {
    if ('repeat' == mode) {
      Navigator.pushNamed(context, RepeatSelectionRoute.routeName);
    } else if ('learn' == mode) {
      Navigator.pushNamed(context, VerbSelectionmodeSelectionRoute.routeName);
    }
  }

  IconButton _settingsIcon(BuildContext context) {
    return IconButton(
        key: const Key('settingsButton'),
        icon: const Icon(Icons.settings),
        onPressed: () {
          Navigator.pushNamed(context, SettingsView.routeName);
        });
  }
}

==> cramr_ui_lib-1.0.16.tar.gz: lib/routes/learn_or_repeat_route.dart <==
import 'package:cramr_ui_lib/routes/repeat_selection_route.dart';
import 'package:cramr_ui_lib/routes/verb_selectionmode_selection_route.dart';
import 'package:flutter/material.dart';

import '../ads/safe_banner_ad_widget.dart';
import '../settings/settings_controller.dart';
import '../settings/settings_view.dart';
import '../theme/custom_theme.dart';
import '../util/text_size_limiter.dart';

class LearnOrRepeatRoute extends StatefulWidget {
  static const routeName = '/learnOrRepeatRoute';

  final SettingsController settingsController;
  final SafeBannerAdWidget safeBannerAdWidget;

  const LearnOrRepeatRoute(
      {super.key,
      required this.settingsController,
      required this.safeBannerAdWidget});

  @override
  State<StatefulWidget> createState() => LearnOrRepeatRouteState();
}

class LearnOrRepeatRouteState extends State<LearnOrRepeatRoute> {
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: widget.settingsController,
        builder: (BuildContext context, Widget? child) {
          return MaterialApp(
              debugShowCheckedModeBanner: false,
              themeMode: widget.settingsController.themeMode,
              theme: CustomTheme.lightTheme,
              darkTheme: ThemeData.dark(),
              home: SafeArea(
                  child: Scaffold(
                appBar: AppBar(
                  actions: [_settingsIcon(context)],
                ),
                body: Column(
                  children: [
                    Expanded(
                        child: ListView(
                      key: const Key('LearnOrRepeatListView'),
                      children: [
                        _buildCard(context, const Key('repeat_key'), 'repeat',
                            'Je répète', 'Ik herhaal'),
                        _buildCard(context, const Key('learn_key'), 'learn',
                            'J\'apprends', 'Ik leer'),
                      ],
                    )),
                    Container(
                      height: 100.0,
                      alignment: Alignment.center,
                      child: widget.safeBannerAdWidget,
                    )
                  ],
                ),
              )));
        });
  }

  Widget _buildCard(BuildContext context, Key buttonKey, String mode,
      String modeName, String modeTranslation) {
    return Center(
      child: SizedBox(
        width: MediaQuery.of(context).size.width * .95,
        child: Card(
          margin: const EdgeInsets.fromLTRB(30, 15, 30, 15),
          elevation: 20,
          child: Column(
            children: [
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: Text(
                  modeName,
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline3,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 5, 10, 5),
                child: Text(
                  '($modeTranslation)',
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline6,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                  padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                  child: OutlinedButton(
                    key: buttonKey,
                    onPressed: () {
                      _launchNextRoute(context, mode);
                    },
                    style: TextButton.styleFrom(foregroundColor: Colors.blue),
                    child: _iconLearnOrRepeat(mode),
                  )),
            ],
          ),
        ),
      ),
    );
  }

  Widget _iconLearnOrRepeat(String mode) {
    if ('repeat' == mode) {
      return const Icon(Icons.refresh);
    } else if ('learn' == mode) {
      return const Icon(Icons.add);
    }
    return const Icon(Icons.adb_sharp);
  }

  void _launchNextRoute(BuildContext context, String mode) {
    if ('repeat' == mode) {
      Navigator.pushNamed(context, RepeatSelectionRoute.routeName);
    } else if ('learn' == mode) {
      Navigator.pushNamed(context, VerbSelectionmodeSelectionRoute.routeName);
    }
  }

  IconButton _settingsIcon(BuildContext context) {
    return IconButton(
        key: const Key('settingsButton'),
        icon: const Icon(Icons.settings),
        onPressed: () {
          Navigator.pushNamed(context, SettingsView.routeName);
        });
  }
}
